/**
 * NIAID DESIGN SYSTEM
 * Created & Owned by: OCGR, NIAID
 * Version: v1.5.0
 * LICENSE: MIT
 */
"use strict";

var moduleNDS_buttonDynamic = function () {
  'use strict';

  /* =================== PRIVATE METHODS ================= */
  function initializeButtonDynamic() {
    jQuery('.button--dynamic').each(function () {
      jQuery(this).on('click', function () {
        var buttonDynamicPrev = jQuery(this).text();
        var buttonDynamicInactive = jQuery(this).attr('data-button-inactive');
        var buttonDynamicActive = jQuery(this).attr('data-button-active');
        jQuery(this).text(buttonDynamicPrev == buttonDynamicActive ? buttonDynamicInactive : buttonDynamicActive);
      });
    });
  }

  /* =================== PUBLIC METHODS ================== */
  function init() {
    initializeButtonDynamic();
  }

  /* =============== EXPORT PUBLIC METHODS =============== */
  return {
    init: init
  };
}();
var moduleNDS_input = function () {
  'use strict';

  /* =================== PRIVATE METHODS ================= */
  // enableKeyboardAccessibility - Functionality to support keyboard accessibility on radio and checkbox inputs.
  function enableKeyboardAccessibility() {
    var inputElements = document.querySelectorAll('.input--radio, .input--checkbox, .facet-item');
    for (var i = 0; i < inputElements.length; i++) {
      inputElements[i].addEventListener('keydown', function (e) {
        if (e.code === "Enter" || e.keyCode === "13" || e.code === "Space" || e.keyCode === "23") {
          e.target.querySelector('input').click();
        }
      });
    }
    var facetItems = document.querySelectorAll('.facet-item');
    for (var j = 0; j < facetItems.length; j++) {
      if (!facetItems[j].hasAttribute('tabindex')) {
        facetItems[j].setAttribute('tabindex', '0');
      }
      if (!facetItems[j].querySelector('input').hasAttribute('tabindex')) {
        facetItems[j].querySelector('input').setAttribute('tabindex', '-1');
      }
    }
  }

  /* =================== PUBLIC METHODS ================== */
  function init() {
    enableKeyboardAccessibility();
  }

  /* =============== EXPORT PUBLIC METHODS =============== */
  return {
    init: init
  };
}();
// Dependencies
//  - Bootstrap Datepicker
//  - jQuery

var moduleNDS_datepicker = function () {
  'use strict';

  /* =================== PRIVATE METHODS ================= */
  // initInputDatePicker - Initializes the Date Picker component through the Bootstrap Datetimepicker library.
  function initInputDatePicker() {
    jQuery('.input--date-picker').each(function () {
      if (jQuery(this).find('input').attr('nds-date-picker') == 'true') {
        jQuery(this).find('input').datepicker();
      }
    });
  }

  /* =================== PUBLIC METHODS ================== */
  function init() {
    initInputDatePicker();
  }

  /* =============== EXPORT PUBLIC METHODS =============== */
  return {
    init: init
  };
}();
var moduleNDS_select = function () {
  'use strict';

  /* =================== PRIVATE METHODS ================= */
  function initInputSelect() {
    jQuery('[data-toggle="tooltip"]').tooltip();
    jQuery('select').each(function () {
      if (jQuery(this).attr('nds-select') == 'true') {
        jQuery(this).select2({
          minimumResultsForSearch: 10
        });
        if (jQuery(this).val() != "") {
          jQuery(this).siblings('.select2-container').addClass('no-clear selection-made');
        }
      }
    });
    jQuery('select').change(function (e, p) {
      if (jQuery(this).attr('nds-select') == 'true') {
        if (!e.target.multiple) {
          jQuery(this).siblings('.select2-container').addClass('selection-made');
          if (!jQuery(this).siblings('.select2-container').find('.single-clear').length && jQuery(this).attr('data-select-all-times') != "true") {
            jQuery(this).siblings('.select2-container').append('<button aria-label="Remove Chip" class="single-clear" tabindex="0"></button>');
          }
        } else {
          jQuery(this).find('option:selected').length > 0 ? jQuery(this).siblings('.select2-container').addClass('selection-made-multi') : jQuery(this).siblings('.select2-container').removeClass('selection-made-multi');
        }
      }
    });

    // Listener to Add Accessibility Compliance to Open Modals
    jQuery('select').on('select2:open', function (e) {
      jQuery('.select2-container').find('.select2-search__field').attr('aria-label', 'Search for choices');
      jQuery('.select2-container').find('.select2-results__options').attr('aria-label', 'Available choices');
    });

    // Add Accessibility Compliane to Loaded Select Field
    jQuery('.select2-selection--single').find('.select2-selection__rendered').attr('aria-label', 'Click to select option.');
    jQuery('.select2-selection--multiple').attr('aria-label', 'Click to select option(s).');

    // Remove selection on click of "X"
    jQuery(document).on('click', '.single-clear', function (e) {
      e.stopPropagation();
      var $selectField = jQuery(this).parent().siblings('select');
      $selectField.prop('selectedIndex', 0);
      var placeholder = $selectField.attr("data-placeholder");
      jQuery(this).parent().removeClass('selection-made');
      jQuery(this).siblings('.selection').find('.select2-selection__rendered').text(placeholder);
      jQuery(this).remove();
    });
  }

  /* =================== PUBLIC METHODS ================== */
  function init() {
    initInputSelect();
  }

  /* =============== EXPORT PUBLIC METHODS =============== */
  return {
    init: init
  };
}();
var moduleNDS_links = function () {
  'use strict';

  var documentTypes = ['pdf', 'PDF', 'doc', 'docx', 'DOC', 'DOCX', 'ppt', 'PPT', 'pptx', 'PPTX', 'xls', 'XLS', 'xlsx', 'XLSX', 'zip', 'ZIP'];

  /* =================== PRIVATE METHODS ================= */
  // initLinkExternal - Adds external link icons to links that qualify as external.
  function initLinkExternal() {
    var externalLinks = document.querySelectorAll('a');
    for (var i = 0; i < externalLinks.length; i++) {
      if (externalLinks[i].innerHTML != "") {
        initDocumentLink(externalLinks[i]);
        var url = externalLinks[i].getAttribute('href');
        var hostname = externalLinks[i].hostname;
        var buttonclassname = externalLinks[i].classList.contains('button-nds') === true;
        var iconclassname = externalLinks[i].classList.contains('icon-nds') === true;
        if (url && hostname !== location.hostname && iconclassname !== true && buttonclassname !== true) {
          url = url.toLowerCase();
          if ((url.indexOf('http://') > -1 || url.indexOf('https://') > -1) && url.indexOf('localhost:3002') <= 0) {
            externalLinks[i].setAttribute('target', '_blank');
            if (externalLinks[i].closest('.global--footer')) {
              externalLinks[i].classList.add('ext-link-footer');
            }
            var linkIcon = document.createElement('span');
            linkIcon.setAttribute('focusable', "false");
            linkIcon.setAttribute('role', "img");
            linkIcon.setAttribute('class', "ext-link-icon");
            linkIcon.setAttribute('aria-label', "(Link is external)");
            externalLinks[i].appendChild(linkIcon);
          }
        }
      }
    }
  }

  // initLinkExternalMailto - Adds envelope icons to mailto links.
  function initLinkExternalMailto() {
    var mailtoLinks = document.querySelectorAll('a[href^="mailto:"]');
    for (var i = 0; i < mailtoLinks.length; i++) {
      var buttonclassname = mailtoLinks[i].classList.contains('button-nds') === true;
      var iconclassname = mailtoLinks[i].classList.contains('icon-nds') === true;
      if (iconclassname !== true && buttonclassname !== true) {
        mailtoLinks[i].classList.add('link--external--mail');
      }
    }
  }
  function initLinkExternalTelephone() {
    var telLinks = document.querySelectorAll('a[href^="tel:"]');
    for (var i = 0; i < telLinks.length; i++) {
      var buttonclassname = telLinks[i].classList.contains('button-nds') === true;
      var iconclassname = telLinks[i].classList.contains('icon-nds') === true;
      if (iconclassname !== true && buttonclassname !== true) {
        telLinks[i].classList.add('link--external--phone');
      }
    }
  }

  // initDocumentLink - Helper function that determines if a document badge should be added to a link.
  function initDocumentLink(link) {
    var href = link.getAttribute('href');
    if (href !== null && href !== "/" && href !== "#") {
      href = href.split('?')[0];
      for (var i = 0; i < documentTypes.length; i++) {
        if (href.indexOf('.' + documentTypes[i]) != -1) {
          addDocumentBadge(link, documentTypes[i]);
          return true;
        }
      }
    }
    return false;
  }

  // addDocumentBadge - Helper function that adds document badges to document links.
  function addDocumentBadge(link, type) {
    var badge = document.createElement('span');
    badge.setAttribute('class', "text-nds text--badge text--badge--document");
    badge.textContent = type.toUpperCase();
    link.insertAdjacentElement('afterend', badge);
  }

  /* =================== PUBLIC METHODS ================== */
  function init() {
    initLinkExternal();
    initLinkExternalMailto();
    initLinkExternalTelephone();
  }

  /* =============== EXPORT PUBLIC METHODS =============== */
  return {
    init: init
  };
}();
// Dependencies
//  - DataTables
//  - jQuery

var moduleNDS_tables = function () {
  'use strict';

  /* =================== PRIVATE METHODS ================= */
  // initTableDefault - Initializes Datatables library.
  function initTableDefault() {
    /* KEY
        Sorting: Add data-tablesort="true" to the <table> tag.
        Numeric Sort Support for a Column: Add data-column-num="true" to the <th> tag of the appropriate column.
    */

    jQuery("table").each(function () {
      if (jQuery(this).attr('nds-datatable') == 'true') {
        var defaultConfigs = {
          "responsive": true,
          "paging": false,
          "info": false,
          "autoWidth": false,
          "searching": false
        };
        if (!(jQuery(this).attr('data-tablesort') == "true")) {
          defaultConfigs['ordering'] = false;
        } else {
          // Determine Column Type
          var columns = [];
          jQuery(this).find('thead').find('th').each(function (i) {
            if (jQuery(this).attr('data-column-num') == "true") {
              columns.push({
                "type": "natural",
                "targets": i
              });
            }
          });
          defaultConfigs['columnDefs'] = columns;
        }
        jQuery(this).dataTable(defaultConfigs);
      } else {
        jQuery(this).wrap('<div class="table-nds--responsive-wrapper">');
      }
    });
  }

  /* =================== PUBLIC METHODS ================== */
  function init() {
    initTableDefault();
  }

  /* =============== EXPORT PUBLIC METHODS =============== */
  return {
    init: init
  };
}();
var moduleNDS_analytics = function () {
  'use strict';

  /* =================== PRIVATE METHODS ================= */
  // addDataAttributes - Adds Data Attributes to certain elements for Google Analytics tracking purposes.
  function addDataAttributes() {
    // Accordion Button
    var accordionCards = document.getElementsByClassName("component--accordion__card");
    for (var i = 0; i < accordionCards.length; i++) {
      var navigationLinks = accordionCards[i].querySelectorAll('button');
      setDataAttributes(navigationLinks, 'data-content', 'accordion-');
    }

    // Breadcrumbs
    var navigationBreadcrumbs = document.getElementsByClassName("navigation--breadcrumbs");
    for (var i = 0; i < navigationBreadcrumbs.length; i++) {
      var breadcrumbs = navigationBreadcrumbs[i].querySelectorAll('a');
      setDataAttributes(breadcrumbs, 'data-content', 'breadcrumbs-');
    }

    // Pagination
    var navigationPagination = document.getElementsByClassName("navigation--pagination");
    for (var i = 0; i < navigationPagination.length; i++) {
      var paginations = navigationPagination[i].querySelectorAll('.pager__item > a');
      setDataAttributes(paginations, 'data-content', 'body-pagination-');
    }

    // Tabs
    var navigationTabs = document.getElementsByClassName("navigation--tabs");
    for (var i = 0; i < navigationTabs.length; i++) {
      var tabs = navigationTabs[i].querySelectorAll('.navigation--tabs__inner-wrapper__tab');
      setDataAttributes(tabs, 'data-content', 'tab-');
    }

    // Generic Body
    var bodyLayouts = document.getElementsByClassName("layouts--body");
    for (var i = 0; i < bodyLayouts.length; i++) {
      var bodyElements = bodyLayouts[i].querySelectorAll('a, button');
      setDataAttributes(bodyElements, 'data-content', 'body-anchor-');
    }

    // Header
    var globalHeaders = document.getElementsByClassName("global--header");
    for (var _i = 0; _i < globalHeaders.length; _i++) {
      // Branding Component
      var logoLinks = globalHeaders[_i].querySelectorAll('.component--branding');
      for (var _j = 0; _j < logoLinks.length; _j++) {
        logoLinks[_j].setAttribute('data-nav', 'header-nav-logo');
      }

      // Generic
      var headerElements = globalHeaders[_i].querySelectorAll('a, button');
      setDataAttributes(headerElements, 'data-nav', 'header-nav-');
    }

    // Facets (Filters)
    var facets = document.getElementsByClassName("facet-item");
    for (var i = 0; i < facets.length; i++) {
      var facetLink = facets[i].querySelector('a');
      var facetLabel = facets[i].querySelector('label');
      var facetName = facets[i].querySelector('.facet-item__value').textContent.trim();
      if (facetName !== "") {
        facetName = facetName.replace(/\//g, '-');
        facetName = facetName.replace(/\s+/g, '-').toLowerCase();
        facetLink.setAttribute('data-content', 'filter-' + facetName);
        facetLabel.setAttribute('data-content', 'filter-' + facetName);
        tagChildren(facetLink, 'data-content');
        tagChildren(facetLabel, 'data-content');
      }

      // Filter Title
      var facetParent = facets[i].closest("ul.item-list__checkbox");
      if (facetParent != null) {
        var titleName = facetParent.getAttribute('data-drupal-facet-alias');
        if (titleName != null) {
          facetLink.setAttribute('data-filter-title', titleName);
          facetLabel.setAttribute('data-filter-title', titleName);
          tagChildren(facetLink, 'data-filter-title');
          tagChildren(facetLabel, 'data-filter-title');
        }
      }
    }

    // Primary Navigation
    var primaryNavigations = document.getElementsByClassName("navigation--primary");
    for (var i = 0; i < primaryNavigations.length; i++) {
      var _navigationLinks = primaryNavigations[i].querySelectorAll('.navigation--primary__item');
      for (var _j2 = 0; _j2 < _navigationLinks.length; _j2++) {
        var navItem = _navigationLinks[_j2].children[0];
        if (hasClass(navItem, 'navigation--dropdown')) {
          var sectionName = _navigationLinks[_j2].children[0].children[0].textContent.trim();
          if (sectionName !== "") {
            sectionName = sectionName.replace(/\//g, '-');
            sectionName = sectionName.replace(/\s+/g, '-').toLowerCase();
            var dropdownToggle = navItem.querySelectorAll('.navigation--dropdown__toggle');
            setDataAttributes(dropdownToggle, 'data-nav', 'header-nav-' + sectionName + '-');
            var dropdownItems = navItem.querySelectorAll('.navigation--dropdown__menu > a');
            setDataAttributes(dropdownItems, 'data-nav', 'header-nav-' + sectionName + '-');
          }
        } else {
          computeDataAttribute(navItem, 'data-nav', 'header-nav-');
        }
      }
    }

    // Footer
    var globalFooters = document.getElementsByClassName("global--footer");
    for (var i = 0; i < globalFooters.length; i++) {
      // Branding Component
      var _logoLinks = globalFooters[i].querySelectorAll('.image--logo');
      for (var j = 0; j < _logoLinks.length; j++) {
        _logoLinks[j].setAttribute('data-nav', 'footer-nav-logo');
      }

      // Footer Links
      var _navigationLinks2 = globalFooters[i].querySelectorAll('a, button');
      setDataAttributes(_navigationLinks2, 'data-nav', 'footer-nav-');
    }

    // Floating Buttons
    var floatingButtons = document.getElementsByClassName("button--floating");
    setDataAttributes(floatingButtons, 'data-nav', 'header-nav-');

    // Mobile Rail & Local Navigation
    var leftNavigation = document.querySelectorAll(".navigation--mobile-rail__content a, .navigation--local a");
    for (var i = 0; i < leftNavigation.length; i++) {
      var targetedNavigationLinks = [];
      if (!leftNavigation[i].hasAttribute('data-content')) {
        targetedNavigationLinks.push(leftNavigation[i]);
      }
      setDataAttributes(targetedNavigationLinks, 'data-nav', 'nav-left-');
    }
  }

  // computeDataAttribute - Helper function to determine the value of the data attribute.
  function computeDataAttribute(el, dataAttributeName, dataAttributeValuePrefix) {
    var linkText = formatAttributeValue(el);
    if (linkText !== "") {
      el.setAttribute(dataAttributeName, dataAttributeValuePrefix + linkText);
      tagChildren(el, dataAttributeName);
    } else {
      if (hasClass(el, 'button--share')) {
        var typeArray = el.classList[2].split('button--share--');
        var type = typeArray[typeArray.length - 1];
        var prefix = '';
        if (dataAttributeValuePrefix == "header-nav-") {
          prefix = 'header-nav-social-share-';
        } else if (dataAttributeValuePrefix == "footer-nav-") {
          prefix = 'footer-nav-social-share-';
        } else {
          prefix = 'body-social-share-';
        }
        el.setAttribute(dataAttributeName, prefix + type);
        tagChildren(el, dataAttributeName);
      }
    }
  }

  // tagChildren - Helper function to tag child elements of the target.
  function tagChildren(el, dataAttributeName) {
    var dataAttributeValue = el.getAttribute(dataAttributeName);
    var childElements = el.querySelectorAll('i, span, div, img, strong');
    for (var j = 0; j < childElements.length; j++) {
      childElements[j].setAttribute(dataAttributeName, dataAttributeValue);
    }
  }

  /* =================== PUBLIC METHODS ================== */
  function init() {
    addDataAttributes();
  }

  // formatAttributeValue - Finds the text content of an element and formats the value for use in a data attribute.
  function formatAttributeValue(el) {
    var processedValue = el.textContent.trim();
    processedValue = processedValue.replace(/\//g, '-');
    processedValue = processedValue.replace(/\s+/g, '-').toLowerCase();
    return processedValue;
  }

  // setDataAttributes - Public function to add data attributes to elements. Pass the set of elements to tag, the name of the data attribute, and the prefix name for the data attribute.
  function setDataAttributes(els, dataAttributeName, dataAttributeValuePrefix) {
    if (els.length > 0 && els !== undefined) {
      for (var i = 0; i < els.length; i++) {
        if (els[i].hasAttribute(dataAttributeName)) {
          tagChildren(els[i], dataAttributeName);
        } else {
          computeDataAttribute(els[i], dataAttributeName, dataAttributeValuePrefix);
        }
      }
    }
  }

  /* =============== EXPORT PUBLIC METHODS =============== */
  return {
    init: init,
    formatAttributeValue: formatAttributeValue,
    setDataAttributes: setDataAttributes
  };
}();
// Dependencies
//  - jQuery
//  - Modernizr

var moduleNDS_featuredContentCards = function () {
  'use strict';

  /* =================== PRIVATE METHODS ================= */
  // initFeaturedContentCards - Initializes the polyfill for browswers that do not support Object Fit.
  function initFeaturedContentCards() {
    var featuredContentCards = document.getElementsByClassName("block--featured-content-card");
    if (featuredContentCards.length > 0) {
      if (!Modernizr.objectfit) {
        jQuery('.block--featured-content-card').each(function () {
          var $container = jQuery(this).find('.block--featured-content-card__image');
          var imgUrl = $container.find('img').prop('src');
          if (imgUrl) {
            $container.css('backgroundImage', 'url(' + imgUrl + ')').addClass('compat-object-fit');
          }
        });
      }
    }
  }

  /* =================== PUBLIC METHODS ================== */
  function init() {
    initFeaturedContentCards();
  }

  /* =============== EXPORT PUBLIC METHODS =============== */
  return {
    init: init
  };
}();
// Dependencies
//  - Materialize

var moduleNDS_hero = function () {
  'use strict';

  // addHeroClassToBody - Adds the 'style--hero' class to the body if there is a hero present. This is separate from the initialization because users may have a custom hero without wanting the layout offset (or other styling) provided with the style--hero body class.
  function addHeroClassToBody() {
    if (document.querySelectorAll('.block--hero').length > 0) {
      document.body.className += ' style--hero';
    }
  }

  /* =============== EXPORT PUBLIC METHODS =============== */
  return {
    addHeroClassToBody: addHeroClassToBody
  };
}();
// Dependencies
//  - Bootstrap 5

var moduleNDS_accordion = function () {
  'use strict';

  /* =================== PRIVATE METHODS ================= */
  // initAccordion - Initializes the accordion to open sections via the url.
  function initAccordion() {
    var accordions = document.getElementsByClassName("component--accordion");
    if (accordions.length > 0) {
      var hash = window.location.hash;
      var accordionHeaders = document.getElementsByClassName("component--accordion__card__header");
      for (var i = 0; i < accordionHeaders.length; i++) {
        var accordionID = accordionHeaders[i].getAttribute('id');
        if (hash == '#' + accordionID) {
          var accordionButton = accordionHeaders[i].querySelector('.component--accordion__card__header__button');
          accordionButton.setAttribute('aria-expanded', 'true');
          var targetID = accordionButton.getAttribute('data-target').replace('#', '');
          var target = document.getElementById(targetID);
          target.classList.add("show");
          break;
        }
      }
    }
  }

  /* =================== PUBLIC METHODS ================== */
  function init() {
    initAccordion();
  }

  /* =============== EXPORT PUBLIC METHODS =============== */
  return {
    init: init
  };
}();
// Dependencies
//  - Materialize

var moduleNDS_media = function () {
  'use strict';

  /* =================== PRIVATE METHODS ================= */
  // initMaterialBoxed - Initializes the materialboxed functionality of Materialize
  function initMaterialBoxed() {
    if (document.querySelectorAll('.materialboxed').length) {
      var elems = document.querySelectorAll('.materialboxed');
      var instances = M.Materialbox.init(elems);
    }
  }

  /* =================== PUBLIC METHODS ================== */
  function init() {
    initMaterialBoxed();
  }

  /* =============== EXPORT PUBLIC METHODS =============== */
  return {
    init: init
  };
}();
// Dependencies
//  - jQuery

var moduleNDS_mobileSearch = function () {
  'use strict';

  /* =================== PRIVATE METHODS ================= */
  // initMobileSearch - Initializes the mobile search functionality.
  function initMobileSearch() {
    if (jQuery('.component--mobile-search').length > 0) {
      document.querySelector('#component--mobile-search--open').addEventListener("click", function (e) {
        openMobileSearch();
      });
      document.querySelector('#component--mobile-search--close').addEventListener("click", function (e) {
        closeMobileSearch();
      });
      window.addEventListener('resize', function () {
        if (viewportIsMobile && viewportWidthIsDifferent) {
          closeMobileSearch();
        }
      });

      // 508 Compliance Focus Helpers
      jQuery('.skip-to--search').on("focus", function (e) {
        jQuery('.component--mobile-search__wrapper__search-form').find('input.input--text').focus();
      });
      jQuery('.skip-to--close').on("focus", function (e) {
        jQuery('#component--mobile-search--close').focus();
      });
    }
  }

  /* =================== PUBLIC METHODS ================== */
  // openMobileSearch - Displays the mobile search bar.
  function openMobileSearch() {
    document.querySelector('.component--mobile-search__wrapper').style.display = "flex";
    jQuery('.component--mobile-search__wrapper__search-form').find('input.input--text').focus();
  }

  // closeMobileSearch - Hides the mobile search bar.
  function closeMobileSearch() {
    document.querySelector('.component--mobile-search__wrapper').style.display = "none";
    jQuery('#component--mobile-search--open').focus();
  }
  function init() {
    initMobileSearch();
  }

  /* =============== EXPORT PUBLIC METHODS =============== */
  return {
    init: init,
    openMobileSearch: openMobileSearch,
    closeMobileSearch: closeMobileSearch
  };
}();
// Dependencies
//  - Bootstrap

var moduleNDS_modal = function () {
  'use strict';

  /* =================== PRIVATE METHODS ================= */
  //  initComponentModal - Initializes the modal component.
  function initComponentModal() {
    if (document.querySelectorAll('.component--modal').length) {
      var focusableElements = 'button, [href], input, select, textarea, [tabindex]:not([tabindex="-1"])';
      var modalsList = document.getElementsByClassName("component--modal");
      var _loop = function _loop() {
        var firstFocusableElement = modalsList[i].querySelectorAll(focusableElements)[0];
        var focusableContent = modalsList[i].querySelectorAll(focusableElements);
        var lastFocusableElement = focusableContent[focusableContent.length - 1];
        document.addEventListener('keydown', function (e) {
          var isTabPressed = e.key === 'Tab' || e.keyCode === 9;
          if (!isTabPressed) {
            return;
          }
          if (e.shiftKey) {
            if (document.activeElement === firstFocusableElement) {
              lastFocusableElement.focus();
              e.preventDefault();
            }
          } else {
            if (document.activeElement === lastFocusableElement) {
              firstFocusableElement.focus();
              e.preventDefault();
            }
          }
        });
        firstFocusableElement.focus();
      };
      for (var i = 0; i < modalsList.length; i++) {
        _loop();
      }
    }
  }

  /* =================== PUBLIC METHODS ================== */
  function init() {
    initComponentModal();
  }

  /* =============== EXPORT PUBLIC METHODS =============== */
  return {
    init: init
  };
}();
var moduleNDS_toast = function () {
  'use strict';

  var exitTime = 1000;

  /* =================== PRIVATE METHODS ================= */

  // destroyToast - Removes a burnt toast from the DOM.
  function destroyToast(toast) {
    toast.remove();
  }

  /* =================== PUBLIC METHODS ================== */
  // activateToast - Adds a toast to the DOM. Pass a toast element to activate.
  function activateToast(toast) {
    var toastDuration = toast.getAttribute('data-duration') * exitTime;
    if (!hasClass(toast, "show")) {
      toast.classList.add('show');
      setTimeout(function () {
        toast.classList.remove('show');
        toast.classList.add('exit');
        setTimeout(function () {
          destroyToast(toast);
        }, exitTime);
      }, toastDuration);
    }
  }

  /* =============== EXPORT PUBLIC METHODS =============== */
  return {
    activateToast: activateToast
  };
}();
var moduleNDS_uswdsBanner = function () {
  'use strict';

  /* =================== PRIVATE METHODS ================= */
  // initComponentUSWDSBanner - Toggles the USWDS Banner Component open and closed.
  function initComponentUSWDSBanner() {
    if (document.querySelectorAll('#uswds-banner-toggle').length > 0) {
      document.querySelector('#uswds-banner-toggle').addEventListener("click", function (e) {
        if (document.getElementById("uswds-banner-toggle").getAttribute('aria-expanded') == 'true') {
          document.getElementById("uswds-banner-toggle").setAttribute('aria-expanded', 'false');
          document.getElementById("uswds-banner-content").style.display = 'none';
        } else {
          document.getElementById("uswds-banner-toggle").setAttribute('aria-expanded', 'true');
          document.getElementById("uswds-banner-content").style.display = 'block';
        }
      });
    }
  }

  /* =================== PUBLIC METHODS ================== */
  function init() {
    initComponentUSWDSBanner();
  }

  /* =============== EXPORT PUBLIC METHODS =============== */
  return {
    init: init
  };
}();
var moduleNDS_drawer = function () {
  'use strict';

  /* =================== PRIVATE METHODS ================= */
  // initializeNavigationDrawer - Functionality to support the NDS mobile drawer.
  function initializeNavigationDrawer() {
    if (document.querySelectorAll('.navigation--drawer').length > 0) {
      document.querySelector('#global-mobile-menu').addEventListener("click", function (e) {
        document.querySelector('#main-navigation-mobile').classList.add("drawer--open");
        var overlay = getNextSibling(document.querySelector('#main-navigation-mobile'), '.navigation--drawer--overlay');
        overlay.style.display = 'block';
        document.querySelector('.navigation--drawer__top__button-close').focus();
        var tabElements = document.querySelector('#main-navigation-mobile').querySelectorAll('button, a');
        for (var i = 0; i < tabElements.length; i++) {
          tabElements[i].setAttribute('tabindex', '0');
        }
      });
      document.querySelector('.navigation--drawer--overlay').addEventListener("click", function (e) {
        closeMenu();
      });
      document.querySelector('.navigation--drawer__top__button-close').addEventListener("click", function (e) {
        closeMenu();
      });
      window.addEventListener('resize', function () {
        if (viewportWidthIsDifferent) {
          closeMenu();
        }
      });

      // 508 Compliance Focus Helpers
      document.querySelector('.skip-to--top').addEventListener("focus", function (e) {
        document.querySelector('.navigation--drawer__top__button-close').focus();
      });
      document.querySelector('.skip-to--back').addEventListener("focus", function (e) {
        var tabElements = document.querySelector('.navigation--drawer__inner').querySelectorAll('button, a');
        if (hasClass(tabElements[tabElements.length - 1], "ext-link-icon")) {
          tabElements[tabElements.length - 2].focus();
        } else {
          tabElements[tabElements.length - 1].focus();
        }
      });
    }
  }

  // closeMenu - Helper function to close the mobile drawer.
  function closeMenu() {
    document.querySelector('#global-mobile-menu').focus();
    document.querySelector('#main-navigation-mobile').classList.remove("drawer--open");
    var overlay = getNextSibling(document.querySelector('#main-navigation-mobile'), '.navigation--drawer--overlay');
    overlay.style.display = 'none';
    var tabElements = document.querySelector('#main-navigation-mobile').querySelectorAll('button, a');
    for (var i = 0; i < tabElements.length; i++) {
      tabElements[i].setAttribute('tabindex', '-1');
    }
  }

  /* =================== PUBLIC METHODS ================== */
  function init() {
    initializeNavigationDrawer();
  }

  /* =============== EXPORT PUBLIC METHODS =============== */
  return {
    init: init
  };
}();
// Dependencies
//  - jQuery

var moduleNDS_dropdown = function () {
  'use strict';

  /* =================== PRIVATE METHODS ================= */
  // initNavigationDropdown - Initializes the dropdown component.
  function initNavigationDropdown() {
    jQuery(".navigation--dropdown.hover").on('mouseover', function () {
      openDropdown(jQuery(this));
    });
    jQuery(".navigation--dropdown.hover").on('mouseout', function () {
      closeDropdown(jQuery(this));
    });
    jQuery(".navigation--dropdown").on('click', function () {
      if (!jQuery(this).hasClass('hover') && isDropdownOpen(jQuery(this))) {
        closeDropdown(jQuery(this));
      } else if (!jQuery(this).hasClass('hover') && !isDropdownOpen(jQuery(this))) {
        openDropdown(jQuery(this));
      }
    });
    jQuery(".navigation--dropdown").on('focusout', function (e) {
      if (this.contains(e.relatedTarget)) {
        return;
      }
      closeDropdown(jQuery(this));
    });
  }

  // isDropdownOpen = Helper function to determine if the dropdown is open.
  function isDropdownOpen($el) {
    return $el.hasClass('is-open');
  }

  // openDropdown - Helper function to open the dropdown.
  function openDropdown($el) {
    $el.addClass('is-open');
    $el.find('.navigation--dropdown__toggle').attr('aria-expanded', 'true');
  }

  // removeClass - Helper function to close the dropdown.
  function closeDropdown($el) {
    $el.removeClass('is-open');
    $el.find('.navigation--dropdown__toggle').attr('aria-expanded', 'false');
  }

  /* =================== PUBLIC METHODS ================== */
  function init() {
    initNavigationDropdown();
  }

  /* =============== EXPORT PUBLIC METHODS =============== */
  return {
    init: init
  };
}();
var moduleNDS_navigationLocal = function () {
  'use strict';

  /* =================== PRIVATE METHODS ================= */
  // initializeNavigationLocal - Adds keyboard support for the local navigation component.
  function initializeNavigationLocal() {
    var localNavigationItems = document.querySelectorAll('.card-header');
    for (var i = 0; i < localNavigationItems.length; i++) {
      localNavigationItems[i].addEventListener('keydown', function (e) {
        if (e.code === "Enter" || e.keyCode === "13" || e.code === "Space" || e.keyCode === "23") {
          e.target.click();
        }
      });
    }
    jQuery('.navigation--local').each(function () {
      if (jQuery(this).attr('data-sticky') == "true") {
        stickyElement(".navigation--local", 0, "all and (min-width: 992px)");
      }
    });
    jQuery('.card-header').on('click', function () {
      var attr = jQuery(this).attr('data-toggle');
      if (typeof attr !== 'undefined' && attr !== false) {
        var newlyOpenedId = jQuery(this).attr('id');
        var headerLevel = jQuery(this).attr('class').split('level-')[1][0];
        var targetLevel = ".level-" + headerLevel;
        jQuery(targetLevel).each(function () {
          var currentItemID = jQuery(this).attr('id');
          if (typeof currentItemID !== 'undefined' && currentItemID !== false) {
            if (currentItemID != newlyOpenedId) {
              closeMenuItem(jQuery(this));
            }
          }
        });
      }
    });
  }

  // closeMenuItem - Closes a particular accordion within the local navigation.
  function closeMenuItem($item) {
    $item.attr('aria-expanded', 'false').removeClass('collapsed');
    var dataTargetValue = $item.attr('data-target');
    jQuery(dataTargetValue).removeClass('show');
  }

  /* =================== PUBLIC METHODS ================== */
  function init() {
    initializeNavigationLocal();
  }

  /* =============== EXPORT PUBLIC METHODS =============== */
  return {
    init: init
  };
}();
// Dependencies
//  - jQuery
//  - Materialize
//  - Stickybits

var moduleNDS_pageContents = function () {
  'use strict';

  /* =================== PRIVATE METHODS ================= */
  // initPageContents - Initializes the Page Contents functionality.
  function initPageContents() {
    var initialized = false;
    if (viewportPreviousWidth >= viewportMobileBreakpoint) {
      initialized = true;
      computePageContents();
    }
    window.onresize = function (e) {
      if (!initialized && viewportWidthIsDifferent) {
        if (viewportPreviousWidth >= viewportMobileBreakpoint) {
          initialized = true;
          computePageContents();
        }
      }
    };
  }

  // computePageContents - Computes the sections of a page from available H2's.
  function computePageContents() {
    var headings = jQuery('.layouts--body').children('h2');
    var $tocList = jQuery('.navigation--page-contents__wrapper__list');
    for (var i = 0; i < headings.length; i++) {
      var headingID = 'scrollspy-section-' + jQuery(headings[i]).text();
      var dataNavValue = moduleNDS_analytics.formatAttributeValue(headings[i]);
      headingID = headingID.replace(/\//g, '-');
      headingID = headingID.replace(/\s+/g, '-').replace('&', 'and').toLowerCase();
      $tocList.append('<li class="navigation--page-contents__wrapper__list__item"><a href="#' + headingID + '" data-nav="nav-right-' + dataNavValue + '">' + jQuery(headings[i]).text() + '</a></li>');
      jQuery(headings[i]).nextUntil("h2").addBack().wrapAll('<div id="' + headingID + '" class="component-nds component--scrollspy-section scrollspy section">');
    }
    jQuery('.scrollspy').scrollSpy();
    jQuery('.navigation--page-contents').find('.icon--loader').hide();
    jQuery('.navigation--page-contents').each(function () {
      if (jQuery(this).attr('data-sticky') == "true") {
        stickyElement(".navigation--page-contents", 32, "all and (min-width: 992px)");
      }
    });
  }

  /* =================== PUBLIC METHODS ================== */
  function init() {
    initPageContents();
  }

  /* =============== EXPORT PUBLIC METHODS =============== */
  return {
    init: init
  };
}();
var moduleNDS_tabs = function () {
  'use strict';

  /* =================== PRIVATE METHODS ================= */
  // initNavigationTabs - Initializes tabs.
  function initNavigationTabs() {
    var tabs = document.querySelectorAll('.navigation--tabs__inner-wrapper__tab');
    for (var i = 0; i < tabs.length; i++) {
      tabs[i].addEventListener('click', function () {
        var activeClass = 'active';
        var tabParent = this.closest('.navigation--tabs');
        var relatedTabs = tabParent.querySelectorAll('.navigation--tabs__inner-wrapper__tab');
        if (!hasClass(this, activeClass)) {
          for (var j = 0; j < relatedTabs.length; j++) {
            if (hasClass(relatedTabs[j], activeClass)) {
              relatedTabs[j].classList.remove(activeClass);
            }
          }
          this.classList.add(activeClass);
        }
      });
    }
  }

  /* =================== PUBLIC METHODS ================== */
  function init() {
    initNavigationTabs();
  }

  /* =============== EXPORT PUBLIC METHODS =============== */
  return {
    init: init
  };
}();